@@ -6,9 +6,11 @@ import qualified GI.GLib.Config as GLib
 
 
 main :: IO ()
-main = setupBinding name version verbose overridesFile inheritedOverrides outputDir
+main = setupBinding name version pkgName pkgVersion verbose overridesFile inheritedOverrides outputDir
   where name = "HarfBuzz"
         version = "0.0"
+        pkgName = "gi-harfbuzz"
+        pkgVersion = "0.0.5"
         overridesFile = Just "HarfBuzz.overrides"
         verbose = False
         outputDir = Nothing
